==> vtk-8.1.1-2-aarch64.pkg.tar.xz: vtk/vtkTemporalFractal.java <==
// java wrapper for vtkTemporalFractal object
//

package vtk;
import vtk.*;

public class vtkTemporalFractal extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFractalValue_2(double id0);
  public void SetFractalValue(double id0)
    { SetFractalValue_2(id0); }

  private native double GetFractalValue_3();
  public double GetFractalValue()
    { return GetFractalValue_3(); }

  private native void SetMaximumLevel_4(int id0);
  public void SetMaximumLevel(int id0)
    { SetMaximumLevel_4(id0); }

  private native int GetMaximumLevel_5();
  public int GetMaximumLevel()
    { return GetMaximumLevel_5(); }

  private native void SetDimensions_6(int id0);
  public void SetDimensions(int id0)
    { SetDimensions_6(id0); }

  private native int GetDimensions_7();
  public int GetDimensions()
    { return GetDimensions_7(); }

  private native void SetGhostLevels_8(int id0);
  public void SetGhostLevels(int id0)
    { SetGhostLevels_8(id0); }

  private native int GetGhostLevels_9();
  public int GetGhostLevels()
    { return GetGhostLevels_9(); }

  private native void GhostLevelsOn_10();
  public void GhostLevelsOn()
    { GhostLevelsOn_10(); }

  private native void GhostLevelsOff_11();
  public void GhostLevelsOff()
    { GhostLevelsOff_11(); }

  private native void SetGenerateRectilinearGrids_12(int id0);
  public void SetGenerateRectilinearGrids(int id0)
    { SetGenerateRectilinearGrids_12(id0); }

  private native int GetGenerateRectilinearGrids_13();
  public int GetGenerateRectilinearGrids()
    { return GetGenerateRectilinearGrids_13(); }

  private native void GenerateRectilinearGridsOn_14();
  public void GenerateRectilinearGridsOn()
    { GenerateRectilinearGridsOn_14(); }

  private native void GenerateRectilinearGridsOff_15();
  public void GenerateRectilinearGridsOff()
    { GenerateRectilinearGridsOff_15(); }

  private native void SetDiscreteTimeSteps_16(int id0);
  public void SetDiscreteTimeSteps(int id0)
    { SetDiscreteTimeSteps_16(id0); }

  private native int GetDiscreteTimeSteps_17();
  public int GetDiscreteTimeSteps()
    { return GetDiscreteTimeSteps_17(); }

  private native void DiscreteTimeStepsOn_18();
  public void DiscreteTimeStepsOn()
    { DiscreteTimeStepsOn_18(); }

  private native void DiscreteTimeStepsOff_19();
  public void DiscreteTimeStepsOff()
    { DiscreteTimeStepsOff_19(); }

  private native void SetTwoDimensional_20(int id0);
  public void SetTwoDimensional(int id0)
    { SetTwoDimensional_20(id0); }

  private native int GetTwoDimensional_21();
  public int GetTwoDimensional()
    { return GetTwoDimensional_21(); }

  private native void TwoDimensionalOn_22();
  public void TwoDimensionalOn()
    { TwoDimensionalOn_22(); }

  private native void TwoDimensionalOff_23();
  public void TwoDimensionalOff()
    { TwoDimensionalOff_23(); }

  private native void SetAsymetric_24(int id0);
  public void SetAsymetric(int id0)
    { SetAsymetric_24(id0); }

  private native int GetAsymetric_25();
  public int GetAsymetric()
    { return GetAsymetric_25(); }

  private native void SetAdaptiveSubdivision_26(int id0);
  public void SetAdaptiveSubdivision(int id0)
    { SetAdaptiveSubdivision_26(id0); }

  private native int GetAdaptiveSubdivision_27();
  public int GetAdaptiveSubdivision()
    { return GetAdaptiveSubdivision_27(); }

  private native void AdaptiveSubdivisionOn_28();
  public void AdaptiveSubdivisionOn()
    { AdaptiveSubdivisionOn_28(); }

  private native void AdaptiveSubdivisionOff_29();
  public void AdaptiveSubdivisionOff()
    { AdaptiveSubdivisionOff_29(); }

  public vtkTemporalFractal() { super(); }

  public vtkTemporalFractal(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-2-aarch64.pkg.tar.xz: vtk/vtkTemporalFractal.java <==
// java wrapper for vtkTemporalFractal object
//

package vtk;
import vtk.*;

public class vtkTemporalFractal extends vtkAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetFractalValue_2(double id0);
  public void SetFractalValue(double id0)
    { SetFractalValue_2(id0); }

  private native double GetFractalValue_3();
  public double GetFractalValue()
    { return GetFractalValue_3(); }

  private native void SetMaximumLevel_4(int id0);
  public void SetMaximumLevel(int id0)
    { SetMaximumLevel_4(id0); }

  private native int GetMaximumLevel_5();
  public int GetMaximumLevel()
    { return GetMaximumLevel_5(); }

  private native void SetDimensions_6(int id0);
  public void SetDimensions(int id0)
    { SetDimensions_6(id0); }

  private native int GetDimensions_7();
  public int GetDimensions()
    { return GetDimensions_7(); }

  private native void SetGhostLevels_8(int id0);
  public void SetGhostLevels(int id0)
    { SetGhostLevels_8(id0); }

  private native int GetGhostLevels_9();
  public int GetGhostLevels()
    { return GetGhostLevels_9(); }

  private native void GhostLevelsOn_10();
  public void GhostLevelsOn()
    { GhostLevelsOn_10(); }

  private native void GhostLevelsOff_11();
  public void GhostLevelsOff()
    { GhostLevelsOff_11(); }

  private native void SetGenerateRectilinearGrids_12(int id0);
  public void SetGenerateRectilinearGrids(int id0)
    { SetGenerateRectilinearGrids_12(id0); }

  private native int GetGenerateRectilinearGrids_13();
  public int GetGenerateRectilinearGrids()
    { return GetGenerateRectilinearGrids_13(); }

  private native void GenerateRectilinearGridsOn_14();
  public void GenerateRectilinearGridsOn()
    { GenerateRectilinearGridsOn_14(); }

  private native void GenerateRectilinearGridsOff_15();
  public void GenerateRectilinearGridsOff()
    { GenerateRectilinearGridsOff_15(); }

  private native void SetDiscreteTimeSteps_16(int id0);
  public void SetDiscreteTimeSteps(int id0)
    { SetDiscreteTimeSteps_16(id0); }

  private native int GetDiscreteTimeSteps_17();
  public int GetDiscreteTimeSteps()
    { return GetDiscreteTimeSteps_17(); }

  private native void DiscreteTimeStepsOn_18();
  public void DiscreteTimeStepsOn()
    { DiscreteTimeStepsOn_18(); }

  private native void DiscreteTimeStepsOff_19();
  public void DiscreteTimeStepsOff()
    { DiscreteTimeStepsOff_19(); }

  private native void SetTwoDimensional_20(int id0);
  public void SetTwoDimensional(int id0)
    { SetTwoDimensional_20(id0); }

  private native int GetTwoDimensional_21();
  public int GetTwoDimensional()
    { return GetTwoDimensional_21(); }

  private native void TwoDimensionalOn_22();
  public void TwoDimensionalOn()
    { TwoDimensionalOn_22(); }

  private native void TwoDimensionalOff_23();
  public void TwoDimensionalOff()
    { TwoDimensionalOff_23(); }

  private native void SetAsymmetric_24(int id0);
  public void SetAsymmetric(int id0)
    { SetAsymmetric_24(id0); }

  private native int GetAsymmetric_25();
  public int GetAsymmetric()
    { return GetAsymmetric_25(); }

  private native void SetAdaptiveSubdivision_26(int id0);
  public void SetAdaptiveSubdivision(int id0)
    { SetAdaptiveSubdivision_26(id0); }

  private native int GetAdaptiveSubdivision_27();
  public int GetAdaptiveSubdivision()
    { return GetAdaptiveSubdivision_27(); }

  private native void AdaptiveSubdivisionOn_28();
  public void AdaptiveSubdivisionOn()
    { AdaptiveSubdivisionOn_28(); }

  private native void AdaptiveSubdivisionOff_29();
  public void AdaptiveSubdivisionOff()
    { AdaptiveSubdivisionOff_29(); }

  public vtkTemporalFractal() { super(); }

  public vtkTemporalFractal(long id) { super(id); }
  public native long   VTKInit();

}
